function playRealMedia()
{
	if ( G2_getClipRef("AUDIO_CLIP") != null ) 
	{
		//There is an audio clip, so begin playing it.
		if (noAudioPlay == true)
		{
		}
		else
		{
			if (parent.Toolbar != null && G2_getPlayState("AUDIO_CLIP",parent.Toolbar.document) != G2_STOPPED)
			{
				G2_stop("AUDIO_CLIP",parent.Toolbar.document);
			}
			G2_play("AUDIO_CLIP");
		}
	}
	else if ( (getLayerRef("VideoLayer") != null) && (G2_getClipRef("VIDEO_CLIP") != null) )
	{
		//There is a video clip, so begin playing it.
		if (noVideoPlay == true)
		{
		}
		else
		{
			if (parent.Toolbar != null && G2_getPlayState("AUDIO_CLIP",parent.Toolbar.document) != G2_STOPPED)
			{
				G2_stop("AUDIO_CLIP",parent.Toolbar.document);
			}
			G2_play("VIDEO_CLIP");
		}
	}
}


